<%- include('../../partials/messages') %>
<div class="side-page dashboard">
  <div
    class="mini-header d-flex justify-content-between flex-wrap flex-md nowrap align-items-center pt-3 pb-2 mb-3 border-bottom-custom"
  >
    <h1 class="h2">Customers</h1>
    <div class="btn-toolbar mb-2 mb-md 0">
      <div class="btn-group me-2">
        <a href="/admin/add" class="btn btn-sm btn-outline-secondary"
          >+ New User</a
        >
      </div>
    </div>
  </div>

  <div class="table-responsive">
    <table class="table table-striped table-sm">
      <thead>
        <tr class="table-head">
          <th scope="col">First Name</th>
          <th scope="col">Last Name</th>
          <th scope="col">Email</th>
          <th scope="col" class="text-end">Action</th>
        </tr>
      </thead>

      <tbody>
        <% customers.forEach(element => { %>
        <tr class="align-middle">
          <td><%= element.firstName %></td>
          <td><%= element.lastName %></td>
          <td><%= element.email %></td>
          <td class="text-end">
            <div class="d-flex flex-row justify-content-end gap-2">
              <a
                href="/admin/view/<%= element._id %>"
                type="button"
                class="btn btn-primary btn-small"
              >
                <i class="bi bi-eye"></i>
              </a>

              <a
                href="/admin/edit/<%= element._id %>"
                type="button"
                class="btn btn-warning btn-small"
              >
                <i class="bi bi-pencil"></i>
              </a>

              <form
                action="/edit/<%= element._id %>?_method=DELETE"
                method="POST"
                class="position-relative"
              >
                <button
                  type="button"
                  data-bs-toggle="modal"
                  data-bs-target="#deleteModal"
                  data-user-id="<%= element._id %>"
                  data-user-firstname="<%= element.firstName %>"
                  data-user-lastname="<%= element.lastName %>"
                  class="btn btn-danger btn-small delete-button"
                >
                  <i class="bi bi-person-x"></i>
                </button>
              </form>
            </div>
          </td>
        </tr>
        <% }) %>
      </tbody>
    </table>
  </div>

  <div class="modal fade" tabindex="-1" role="dialog" id="deleteModal">
    <div class="modal-dialog" role="document">
      <div class="modal-content">
        <div class="modal-header">
          <div class="modal-title">Delete Customer?</div>
          <button
            type="button"
            class="btn-close"
            data-bs-dismiss="modal"
            aria-label="Close"
          ></button>
        </div>
        <div class="modal-body">
          <p>
            This will remove the customer record of
            <b class="fw-bold" id="modal-user-name"></b><br />
          </p>
          <p>Are you sure?</p>
        </div>
        <div class="modal-footer">
          <button
            type="button"
            class="btn btn-secondary"
            data-bs-dismiss="modal"
          >
            Close
          </button>
          <form
            action="/admin/edit/<%= customers._id %>?_method=DELETE"
            method="POST"
            class="position-relative"
          >
            <button type="submit" class="btn btn-danger btn-primary">
              Yes, Remove Customer
            </button>
          </form>
        </div>
      </div>
    </div>
  </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
  $(document).ready(function () {
    $('.delete-button').click(function () {
      const userId = $(this).data('user-id');
      const firstName = $(this).data('user-firstname');
      const lastName = $(this).data('user-lastname');

      $('#modal-user-name').text(firstName + ' ' + lastName);
      $('#deleteModal form').attr(
        'action',
        '/admin/edit/' + userId + '?_method=DELETE'
      );
    });
  });
</script>

<% if (customers.length > 0) { %>
<nav aria-label="Dashboard Pagination">
  <ul class="pagination justify-content-center mt-5">
    <!-- First Page Link -->
    <% if (current == 1) { %>
    <li class="page-item disabled"><a href="#" class="page-link">First</a></li>
    <% } else { %>
    <li class="page-item">
      <a href="/admin/customers/?page=1" class="page-link">First</a>
    </li>
    <% } %>

    <!-- Calculate Starting Page Number -->
    <% var startPage = (Number(current) > 5 ? Number(current) - 4 : 1); %>

    <!-- Ellipsis for Skipped Pages -->
    <% if (startPage !== 1) { %>
    <li class="page-item disabled"><a href="#" class="page-link">...</a></li>
    <% } %>

    <!-- Page Number Links -->
    <% for (var i = startPage; i <= (Number(current) + 4) && i <= pages; i++) {
    %> <% if (i == current) { %>
    <li class="page-item disabled">
      <a href="#" class="page-link"><%= i %></a>
    </li>
    <% } else { %>
    <li class="page-item">
      <a href="/admin/customers/?page=<%= i %>" class="page-link"><%= i %></a>
    </li>
    <% } %> <% if (i == Number(current) + 4 && i < pages) { %>
    <li class="page-item disabled"><a href="#" class="page-link">...</a></li>
    <% } %> <% } %>

    <!-- Last Page Link -->
    <% if (current == pages) { %>
    <li class="page-item disabled"><a href="#" class="page-link">Last</a></li>
    <% } else { %>
    <li class="page-item">
      <a href="/admin/customers/?page=<%= pages %>" class="page-link">Last</a>
    </li>
    <% } %>
  </ul>
</nav>
<% } %>
